@@ -27,12 +27,9 @@ class HttpClient:
             Passed as the params parameter of the requests.get request.
         
         """
-        try:
-            res = requests.get(self.base_url + url, params=params, headers=self.headers)
-            res.raise_for_status()
-            return res.json()
-        except requests.exceptions.RequestException as err:
-            raise SystemExit(err)
+        res = requests.get(self.base_url + url, params=params, headers=self.headers)
+        res.raise_for_status()
+        return res.json()
 
     def http_post(self, url, params={}, data={}):
         """Make a post request.
@@ -43,12 +40,11 @@ class HttpClient:
             URL to make the post request. Is appended to self.base_url.
         params: dict
             Passed as the params parameter of the requests.post request.
+        data: dict
+            Passed as the data parameter of the requests.post request.
         """
-        try:
-            res = requests.post(
-                self.base_url + url, params=params, json=data, headers=self.headers
-            )
-            res.raise_for_status()
-            return res.json()
-        except requests.exceptions.RequestException as err:
-            raise SystemExit(err)
+        res = requests.post(
+            self.base_url + url, params=params, json=data, headers=self.headers
+        )
+        res.raise_for_status()
+        return res.json()
\ No newline at end of file
