@@ -16,6 +16,9 @@ class Model:
         self.query = model_json["query"]
         self.parameters = model_json["nnModelConfig"]
         self.encodings = model_json["columnEncodings"]
+        self.model_type = self.parameters["modelType"]
+        self.conditions = model_json.get("conditionColumns", [])
+        self.has_conditions = (self.model_type == 'RNN_VAE') and len(self.conditions) > 0
 
     def describe(self):
         """Print model metadata - id, query, parameters (model config), encodings.
@@ -24,3 +27,5 @@ class Model:
         print("Query: " + self.query)
         print("Parameters: " + str(self.parameters))
         print("Column Encodings: " + str(self.encodings))
+        if self.has_conditions:
+            print("Columns conditioned on: " + str(self.conditions))
