@@ -1,6 +1,6 @@
 import pandas as pd
-
-from typing import List
+import requests
+from typing import List, Union
 
 from tonic_api.services.models import ModelService
 from tonic_api.classes.model import Model
@@ -50,6 +50,49 @@ class TrainedModel:
         res = self.model_service.sample(self.id, num_rows)
         return self.__convert_to_df(res)
 
+    def conditional_sample(
+        self, conditions: Union[List[dict], pd.DataFrame]
+    ) -> pd.DataFrame:
+        """Generates synthetic samples from from conditional model, or throws an error
+        if the model is not conditional.
+
+        The synthetic samples will be generated based on the specified conditions, with
+        one complete sequence of samples for each condition. Note that the sequences
+        will be returned in the same order as the conditions, as the conditions will
+        be present in the output dataframe.
+        
+        The conditions parameter can be a list of dictionaries, or a pandas DataFrame. 
+        In either case, the values of all condition columns must be specified.
+
+        Parameters
+        ----------
+        conditions : List[dict] or pd.DataFrame
+            List or dataframe of conditions. If a list, each list item should be a 
+            dictionary with keys for each condition column and values for the condition. 
+            If a dataframe, the extra columns will be dropped and the remaining columns 
+            will be used as conditions.
+
+        Returns
+        -------
+        pandas.DataFrame
+            A dataframe of synthetic data.
+        """
+        if not self.model.has_conditions:
+            raise ValueError("Model does not have conditions")
+
+        if isinstance(conditions, pd.DataFrame):
+            columns = conditions.columns.tolist()
+            for col in columns:
+                if col not in self.model.conditions:
+                    print("Ignoring column " + col + " not in conditions")
+            conditions = conditions[self.model.conditions].to_dict("records")
+
+        try:
+            res = self.model_service.conditional_sample(self.id, conditions)
+            return self.__convert_to_df(res)
+        except requests.exceptions.RequestException as err:
+            print('ERROR: {}'.format(err.response.text))
+
     def sample_source(self, num_rows: int=1):
         """Generates samples from source data.
 
@@ -117,6 +160,12 @@ class TrainedModel:
             if encoding == "Categorical"
         ]
 
+    def get_condition_columns(self) -> List[str]:
+        conditions = self.model.conditions
+        if conditions is not None or len(conditions) > 0:
+            return conditions
+        print("No conditions found")
+
     def __convert_to_df(self, sample_response):
         schema = self.__get_schema()
         df = pd.DataFrame(sample_response)
